@@ -12,6 +12,7 @@ if django.VERSION[0] >= 3:
     from django.db.models import JSONField
 else:
     from django.contrib.postgres.fields.jsonb import JSONField
+from django.db.models import UUIDField
 from django.core.exceptions import ValidationError, FieldDoesNotExist
 from django.core.management.color import no_style
 from django.core.serializers import python as serializers
@@ -349,23 +350,25 @@ def reset_db_seq(Model, next_value=None):
                                  If unspecified, set the sequence so the next value is max(id) + 1.
     """
     try:
-        Model._meta.get_field('id')
+        primary_key = Model._meta.get_field('id')
     except FieldDoesNotExist:
         return  # If id field does not exist, do not reset the sequence.
 
+    if isinstance(primary_key, UUIDField):
+        return
+
     with connection.cursor() as cursor:
         if not next_value:
             # Find the highest id value in use if next_value is None or 0.
             cursor.execute(f"SELECT MAX(id) FROM {Model._meta.db_table}")
             highest_value = cursor.fetchone()[0]
-            if not isinstance(highest_value, int):
-                return
 
             # If the table has a max(id) of None, it is empty so start the next value at 1.
             # If the table has a max(id) of 1, start the next value at 2.
             # If the table has a max(id) of 3, start the next value at 4.
             highest_value = highest_value or 0
-            next_value = highest_value + 1
+            if isinstance(highest_value, int):
+                next_value = highest_value + 1
         # The 3rd parameter we send to setval() specifies whether the specified value has already been used.
         # If false, the next value returned will be the specified value.
         # If true,  the next value returned will be the specified value + 1.
